@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -418,6 +418,8 @@ class AdaptiveWindow:
             self.set_adaptive(True)
         else:
             self.set_adaptive(False)
+        if width <= Size.PHONE:
+            adaptive_size = AdaptiveSize.PHONE
         if width <= Size.SMALL:
             adaptive_size = AdaptiveSize.SMALL
         elif width <= Size.MEDIUM:
