@@ -93,6 +93,8 @@ class FullScreen(Gtk.Window, AdaptiveWindow, SignalsHelper):
         self.__label_widget.set_justify(Gtk.Justification.CENTER)
         eventbox = Gtk.EventBox.new()
         eventbox.show()
+        eventbox.set_property("valign", Gtk.Align.END)
+        eventbox.set_property("halign", Gtk.Align.END)
         eventbox.connect("button-release-event",
                          self.__on_image_button_release_event)
         eventbox.connect("realize", self.__on_image_realize)
@@ -287,7 +289,9 @@ class FullScreen(Gtk.Window, AdaptiveWindow, SignalsHelper):
             if allocation.width <= 1 or allocation.height <= 1:
                 return
             behaviour = App().settings.get_value("fullscreen-type").get_int32()
-            behaviour |= (ArtBehaviour.CROP | ArtBehaviour.DARKER)
+            behaviour |= (ArtBehaviour.CROP |
+                          ArtBehaviour.CACHE |
+                          ArtBehaviour.DARKER)
             # We don't want this for background, stored for album cover
             behaviour &= ~ArtBehaviour.ROUNDED
             if isinstance(App().player.current_track, Radio):
@@ -392,6 +396,7 @@ class FullScreen(Gtk.Window, AdaptiveWindow, SignalsHelper):
             self.__update_background(True)
         else:
             self.__background_artwork.set_from_surface(surface)
+            del surface
 
     def __on_key_release_event(self, widget, event):
         """
