@@ -14,17 +14,22 @@ from gi.repository import Gio, GLib
 
 from gettext import gettext as _
 
+from lollypop.menu_sync import SyncAlbumsMenu
+from lollypop.menu_playlists import PlaylistsMenu
 from lollypop.define import App, ViewType, Type
+from lollypop.objects_album import Album
+from lollypop.utils import get_default_storage_type
 
 
 class ArtistMenu(Gio.Menu):
     """
         Contextual menu for artist
     """
-    def __init__(self, artist_id, view_type, header=False):
+    def __init__(self, artist_id, storage_type, view_type, header=False):
         """
             Init artist menu
             @param artist_id as int
+            @param storage_type as StorageType
             @param view_type as ViewType
             @param header as bool
         """
@@ -32,43 +37,7 @@ class ArtistMenu(Gio.Menu):
         if header:
             from lollypop.menu_header import ArtistMenuHeader
             self.append_item(ArtistMenuHeader(artist_id))
-        if not view_type & ViewType.BANNER:
-            from lollypop.menu_playback import ArtistPlaybackMenu
-            self.append_section(_("Playback"), ArtistPlaybackMenu(artist_id))
-        menu = ArtistAlbumsMenu(artist_id, view_type)
-        if menu.get_n_items() != 0:
-            self.append_section(_("Albums"), menu)
-
-
-class ArtistAlbumsMenu(Gio.Menu):
-    """
-        Contextual menu for artist albums
-    """
-
-    def __init__(self, artist_id, view_type):
-        """
-            Init artist albums menu
-            @param artist id as int
-            @param view_type as ViewType
-        """
-        Gio.Menu.__init__(self)
-        self.__artist_id = artist_id
-        self.__set_actions(view_type)
-
-#######################
-# PRIVATE             #
-#######################
-    def __set_actions(self, view_type):
-        """
-            Set artist actions
-            @param view_type as ViewType
-        """
-        go_artist_action = Gio.SimpleAction(name="go_artist_action")
-        App().add_action(go_artist_action)
-        go_artist_action.connect("activate",
-                                 self.__on_go_to_artist_activate)
-        self.append(_("Available albums"), "app.go_artist_action")
-        if view_type & ViewType.BANNER and not view_type & ViewType.ALBUM:
+        if view_type & ViewType.BANNER:
             show_tracks_action = Gio.SimpleAction.new_stateful(
                 "show_tracks_action",
                 None,
@@ -78,16 +47,21 @@ class ArtistAlbumsMenu(Gio.Menu):
             show_tracks_action.connect("change-state",
                                        self.__on_show_tracks_change_state)
             self.append(_("Show tracks"), "app.show_tracks_action")
+        else:
+            from lollypop.menu_playback import ArtistPlaybackMenu
+            self.append_section(_("Playback"),
+                                ArtistPlaybackMenu(artist_id, storage_type))
+        menu = Gio.Menu()
+        self.append_section(_("Artist"), menu)
+        storage_type = get_default_storage_type()
+        album_ids = App().albums.get_ids([artist_id], [], storage_type, True)
+        albums = [Album(album_id) for album_id in album_ids]
+        menu.append_submenu(_("Devices"), SyncAlbumsMenu(albums))
+        menu.append_submenu(_("Playlists"), PlaylistsMenu(albums))
 
-    def __on_go_to_artist_activate(self, action, variant):
-        """
-            Show albums from artists
-            @param Gio.SimpleAction
-            @param GLib.Variant
-        """
-        App().window.container.show_view([Type.ARTISTS],
-                                         [self.__artist_id])
-
+#######################
+# PRIVATE             #
+#######################
     def __on_show_tracks_change_state(self, action, variant):
         """
             Save option and reload view
@@ -97,3 +71,42 @@ class ArtistAlbumsMenu(Gio.Menu):
         action.set_state(variant)
         App().settings.set_value("show-artist-tracks", variant)
         App().window.container.reload_view()
+
+
+class ArtistAlbumsMenu(Gio.Menu):
+    """
+        Contextual menu for artist albums
+    """
+
+    def __init__(self, artist_id, storage_type):
+        """
+            Init artist albums menu
+            @param artist id as int
+        """
+        Gio.Menu.__init__(self)
+        self.__storage_type = storage_type
+        self.__artist_id = artist_id
+        self.__set_actions()
+
+#######################
+# PRIVATE             #
+#######################
+    def __set_actions(self):
+        """
+            Set artist actions
+        """
+        go_artist_action = Gio.SimpleAction(name="go_artist_action")
+        App().add_action(go_artist_action)
+        go_artist_action.connect("activate",
+                                 self.__on_go_to_artist_activate)
+        self.append(_("Available albums"), "app.go_artist_action")
+
+    def __on_go_to_artist_activate(self, action, variant):
+        """
+            Show albums from artists
+            @param Gio.SimpleAction
+            @param GLib.Variant
+        """
+        App().window.container.show_view([Type.ARTISTS],
+                                         [self.__artist_id],
+                                         self.__storage_type)
