@@ -15,7 +15,6 @@ from gi.repository import GLib
 from random import choice, shuffle
 
 from lollypop.logger import Logger
-from lollypop.objects_track import Track
 from lollypop.objects_album import Album
 from lollypop.player_auto_similar import AutoSimilarPlayer
 from lollypop.player_auto_random import AutoRandomPlayer
@@ -106,6 +105,20 @@ class AlbumsPlayer:
         except Exception as e:
             Logger.error("Player::remove_album_by_ids(): %s" % e)
 
+    def remove_track_from_album(self, track, album):
+        """
+            Remove track from album
+            @param track as Track
+            @param album as Album
+        """
+        is_current_track = track == self.current_track
+        if is_current_track:
+            self.next()
+        if album.remove_track(track):
+            self.remove_album(album)
+        elif not is_current_track:
+            self.update_next_prev()
+
     def play_album(self, album):
         """
             Play album
@@ -152,35 +165,6 @@ class AlbumsPlayer:
             album = albums[0]
         self.play_album_for_albums(album, albums)
 
-    def play_uris(self, uris):
-        """
-            Play uris
-            @param uris as [str]
-        """
-        # First get tracks
-        tracks = []
-        for uri in uris:
-            track_id = App().tracks.get_id_by_uri(uri)
-            if track_id is not None:
-                tracks.append(Track(track_id))
-        # Then get album ids
-        album_ids = {}
-        for track in tracks:
-            if track.album.id in album_ids.keys():
-                album_ids[track.album.id].append(track)
-            else:
-                album_ids[track.album.id] = [track]
-        # Create albums with tracks
-        play = True
-        for album_id in album_ids.keys():
-            album = Album(album_id)
-            album.set_tracks(album_ids[album_id])
-            if play:
-                self.play_album(album)
-            else:
-                self.add_album(album)
-        emit_signal(self, "playback-changed")
-
     def set_albums(self, albums):
         """
             Set player albums
