@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -81,9 +81,6 @@ class TuneinPopover(Gtk.Popover):
             Populate view for uri
             @param uri as str
         """
-        if not get_network_available("TUNEIN"):
-            self.__show_message(_("Can't connect to TuneIn…"))
-            return
         if self.__view.get_children():
             return
         self.__populate(uri)
@@ -143,12 +140,15 @@ class TuneinPopover(Gtk.Popover):
             Populate view for uri
             @param uri as str
         """
+        self.__back_btn.set_sensitive(False)
+        self.__home_btn.set_sensitive(False)
+        if not get_network_available("TUNEIN"):
+            self.__show_message(_("Can't connect to TuneIn…"))
+            return
         self.__clear()
         self.__cancellable = Gio.Cancellable()
         self.__spinner.start()
         self.__stack.set_visible_child_name("spinner")
-        self.__back_btn.set_sensitive(False)
-        self.__home_btn.set_sensitive(False)
         self.__label.set_text(_("Please wait…"))
         App().task_helper.load_uri_content(uri,
                                            self.__cancellable,
@@ -291,7 +291,7 @@ class TuneinPopover(Gtk.Popover):
             @param image as Gtk.Image
         """
         if status:
-            bytes = GLib.Bytes(content)
+            bytes = GLib.Bytes.new(content)
             stream = Gio.MemoryInputStream.new_from_bytes(bytes)
             if stream is not None:
                 pixbuf = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
@@ -304,7 +304,9 @@ class TuneinPopover(Gtk.Popover):
                 surface = Gdk.cairo_surface_create_from_pixbuf(pixbuf,
                                                                0,
                                                                None)
+                del pixbuf
                 image.set_from_surface(surface)
+                del surface
         self.__download_images()
 
     def __on_activate_link(self, link, item):
