@@ -341,26 +341,34 @@ class TagReader:
             @return year and timestamp (int, int)
         """
         try:
-            (exists, date) = tags.get_date_index("date", 0)
-            dt = year = timestamp = None
-            if exists:
+            (exists_date, date) = tags.get_date_index("date", 0)
+            (exists_datetime, datetime) = tags.get_date_time_index("datetime",
+                                                                   0)
+            year = timestamp = None
+            if exists_datetime:
+                if datetime.has_year():
+                    year = datetime.get_year()
+                if datetime.has_month():
+                    month = datetime.get_month()
+                else:
+                    month = 1
+                if datetime.has_day():
+                    day = datetime.get_day()
+                else:
+                    day = 1
+            if exists_date and date.valid():
                 year = date.get_year()
-                d = Gst.DateTime.new_local_time(year, 1, 1, 0, 0, 0)
-                dt = d.to_g_date_time()
-                timestamp = dt.to_unix()
-            else:
-                (exists, date) = tags.get_date_time_index("datetime", 0)
-                if exists:
-                    dt = date.to_g_date_time()
-                    if dt is None:
-                        year = date.get_year()
-                        d = Gst.DateTime.new_local_time(year, 1, 1, 0, 0, 0)
-                        dt = d.to_g_date_time()
-                    timestamp = dt.to_unix()
+                month = date.get_month()
+                day = date.get_day()
+
+            if year is not None:
+                gst_datetime = Gst.DateTime.new_local_time(
+                    year, month, day, 0, 0, 0)
+                glib_datetime = gst_datetime.to_g_date_time()
+                timestamp = glib_datetime.to_unix()
             return (year, timestamp)
         except Exception as e:
-            error = "" if tags is None else tags.to_string()
-            Logger.error("TagReader::get_year(): %s, %s", e, error)
+            Logger.error("TagReader::get_year(): %s", e)
         return (None, None)
 
     def get_original_year(self, tags):
@@ -512,7 +520,7 @@ class TagReader:
             @return lyrics as str
         """
         def decode_lyrics(bytes):
-            from lollypop.utils import decodeUnicode, splitUnicode
+            from lollypop.utils_file import decodeUnicode, splitUnicode
             try:
                 prefix = bytes[0:4]
                 if prefix in [b"USLT"]:
@@ -583,7 +591,7 @@ class TagReader:
         """
         def decode_lyrics(bytes_list, encoding):
             lyrics = []
-            from lollypop.utils import decodeUnicode, splitUnicode
+            from lollypop.utils_file import decodeUnicode, splitUnicode
             try:
                 for frame in bytes_list:
                     (l, t) = splitUnicode(frame, encoding)
