@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -18,6 +18,7 @@ from lollypop.objects_radio import Radio
 from lollypop.widgets_player_artwork import ArtworkPlayerWidget
 from lollypop.widgets_player_label import LabelPlayerWidget
 from lollypop.define import App, ArtBehaviour, StorageType, MARGIN_SMALL
+from lollypop.define import ViewType
 from lollypop.helper_gestures import GesturesHelper
 
 
@@ -143,15 +144,15 @@ class ToolbarInfo(Gtk.Bin, ArtworkPlayerWidget, GesturesHelper):
             return
         track = App().player.current_track
         if track.id >= 0:
-            from lollypop.menu_objects import MinTrackMenu, TrackMenuExt
+            from lollypop.menu_objects import TrackMenu, TrackMenuExt
             from lollypop.widgets_menu import MenuBuilder
-            menu = MinTrackMenu(track)
+            menu = TrackMenu(track, ViewType.TOOLBAR, False)
             menu_widget = MenuBuilder(menu)
             menu_widget.show()
             if not track.storage_type & StorageType.EPHEMERAL:
                 menu_ext = TrackMenuExt(track)
                 menu_ext.show()
-                menu_widget.get_child_by_name("main").add(menu_ext)
+                menu_widget.append_widget(menu_ext)
             self.set_state_flags(Gtk.StateFlags.FOCUSED, False)
             popup_widget(menu_widget, self.__eventbox)
 
