@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -14,8 +14,9 @@ from gi.repository import Gtk
 
 from random import shuffle
 
-from lollypop.utils import get_human_duration, tracks_to_albums, popup_widget
-from lollypop.define import App, ArtSize, ViewType
+from lollypop.utils import get_human_duration, popup_widget
+from lollypop.utils_album import tracks_to_albums
+from lollypop.define import App, ArtSize, ViewType, Size
 from lollypop.widgets_banner import BannerWidget
 
 
@@ -53,23 +54,13 @@ class PlaylistBannerWidget(BannerWidget):
             duration = App().playlists.get_duration(playlist_id)
             self.__duration_label.set_text(get_human_duration(duration))
 
-    def set_view_type(self, view_type):
+    def update_for_width(self, width):
         """
-            Update view type
-            @param view_type as ViewType
+            Update banner internals for width, call this before showing banner
+            @param width as int
         """
-        BannerWidget.set_view_type(self, view_type)
-        duration_context = self.__duration_label.get_style_context()
-        title_context = self.__title_label.get_style_context()
-        for c in title_context.list_classes():
-            title_context.remove_class(c)
-        for c in duration_context.list_classes():
-            duration_context.remove_class(c)
-        if view_type & ViewType.ADAPTIVE:
-            title_context.add_class("text-large")
-        else:
-            title_context.add_class("text-x-large")
-            duration_context.add_class("text-large")
+        BannerWidget.update_for_width(self, width)
+        self.__set_internal_size()
 
     @property
     def spinner(self):
@@ -90,6 +81,14 @@ class PlaylistBannerWidget(BannerWidget):
 #######################
 # PROTECTED           #
 #######################
+    def _handle_width_allocate(self, allocation):
+        """
+            Update artwork
+            @param allocation as Gtk.Allocation
+        """
+        if BannerWidget._handle_width_allocate(self, allocation):
+            self.__set_internal_size()
+
     def _on_play_button_clicked(self, button):
         """
             Play playlist
@@ -124,15 +123,35 @@ class PlaylistBannerWidget(BannerWidget):
         """
         from lollypop.widgets_menu import MenuBuilder
         from lollypop.menu_playlist import PlaylistMenu, PlaylistMenuExt
-        menu = PlaylistMenu(self.__playlist_id, App().window.is_adaptive)
+        menu = PlaylistMenu(self.__playlist_id,
+                            self.view_type,
+                            App().window.is_adaptive)
         menu_widget = MenuBuilder(menu)
         if self.__playlist_id >= 0:
             menu_widget = MenuBuilder(menu)
-            main = menu_widget.get_child_by_name("main")
             menu_ext = PlaylistMenuExt(self.__playlist_id)
             menu_ext.show()
-            main.add(menu_ext)
+            menu_widget.append_widget(menu_ext)
         else:
             menu_widget = MenuBuilder(menu)
         menu_widget.show()
         popup_widget(menu_widget, button)
+
+#######################
+# PRIVATE             #
+#######################
+    def __set_internal_size(self):
+        """
+            Update font size
+        """
+        duration_context = self.__duration_label.get_style_context()
+        title_context = self.__title_label.get_style_context()
+        for c in title_context.list_classes():
+            title_context.remove_class(c)
+        for c in duration_context.list_classes():
+            duration_context.remove_class(c)
+        if self.width <= Size.MEDIUM:
+            title_context.add_class("text-large")
+        else:
+            title_context.add_class("text-x-large")
+            duration_context.add_class("text-large")
