@@ -1,4 +1,4 @@
 rm -fr /usr/local/lib/python3.7/site-packages/lollypop/
 ninja -C build install
-echo "Running lollypop"
+reset
 lollypop -e
